@@ -1,5 +1,6 @@
 // smtp-check is a command-line too for checking SMTP setups.
 //
+//go:build !coverage
 // +build !coverage
 
 package main
@@ -24,6 +25,8 @@ import (
 var (
 	port = flag.String("port", "smtp",
 		"port to use for connecting to the MX servers")
+	localName = flag.String("localname", "localhost",
+		"specify the local name for the EHLO command")
 	skipTLSCheck = flag.Bool("skip_tls_check", false,
 		"skip TLS check (useful if connections are blocked)")
 )
@@ -90,6 +93,10 @@ func main() {
 			if err != nil {
 				log.Fatal(err)
 			}
+			err = c.Hello(*localName)
+			if err != nil {
+				log.Fatal(err)
+			}
 
 			config := &tls.Config{
 				// Expect the server to have a certificate valid for the MX
