@@ -9,8 +9,9 @@ import (
 	"bytes"
 	"context"
 	"encoding/base64"
+	"encoding/binary"
 	"fmt"
-	"math/rand"
+	"math/rand/v2"
 	"os"
 	"os/exec"
 	"path/filepath"
@@ -32,12 +33,6 @@ import (
 )
 
 const (
-	// Maximum size of the queue; we reject emails when we hit this.
-	maxQueueSize = 200
-
-	// Give up sending attempts after this duration.
-	giveUpAfter = 20 * time.Hour
-
 	// Prefix for item file names.
 	// This is for convenience, versioning, and to be able to tell them apart
 	// temporary files and other cruft.
@@ -67,17 +62,11 @@ var newID chan string
 
 func generateNewIDs() {
 	// The IDs are only used internally, we are ok with using a PRNG.
-	// We create our own to avoid relying on external sources initializing it
-	// properly.
-	prng := rand.New(rand.NewSource(time.Now().UnixNano()))
-
 	// IDs are base64(8 random bytes), but the code doesn't care.
 	buf := make([]byte, 8)
-	id := ""
 	for {
-		prng.Read(buf)
-		id = base64.RawURLEncoding.EncodeToString(buf)
-		newID <- id
+		binary.NativeEndian.PutUint64(buf, rand.Uint64())
+		newID <- base64.RawURLEncoding.EncodeToString(buf)
 	}
 }
 
@@ -88,12 +77,6 @@ func init() {
 
 // Queue that keeps mail waiting for delivery.
 type Queue struct {
-	// Items in the queue. Map of id -> Item.
-	q map[string]*Item
-
-	// Mutex protecting q.
-	mu sync.RWMutex
-
 	// Couriers to use to deliver mail.
 	localC  courier.Courier
 	remoteC courier.Courier
@@ -106,6 +89,18 @@ type Queue struct {
 
 	// Aliases resolver.
 	aliases *aliases.Resolver
+
+	// The maximum number of items in the queue.
+	MaxItems int
+
+	// Give up sending attempts after this long.
+	GiveUpAfter time.Duration
+
+	// Mutex protecting q.
+	mu sync.RWMutex
+
+	// Items in the queue. Map of id -> Item.
+	q map[string]*Item
 }
 
 // New creates a new Queue instance.
@@ -120,6 +115,16 @@ func New(path string, localDomains *set.String, aliases *aliases.Resolver,
 		localDomains: localDomains,
 		path:         path,
 		aliases:      aliases,
+
+		// We reject emails when we hit this.
+		// Note the actual default used in the daemon is set in the config. We
+		// put a non-zero value here just to be safe.
+		MaxItems: 100,
+
+		// We give up sending (and return a DSN) after this long.
+		// Note the actual default used in the daemon is set in the config. We
+		// put a non-zero value here just to be safe.
+		GiveUpAfter: 20 * time.Hour,
 	}
 	return q, err
 }
@@ -160,8 +165,8 @@ func (q *Queue) Put(tr *trace.Trace, from string, to []string, data []byte) (str
 	tr = tr.NewChild("Queue.Put", from)
 	defer tr.Finish()
 
-	if q.Len() >= maxQueueSize {
-		tr.Errorf("queue full")
+	if nItems := q.Len(); nItems >= q.MaxItems {
+		tr.Errorf("queue full (%d items)", nItems)
 		return "", errQueueFull
 	}
 	putCount.Add(1)
@@ -196,6 +201,9 @@ func (q *Queue) Put(tr *trace.Trace, from string, to []string, data []byte) (str
 				r.Type = Recipient_EMAIL
 			case aliases.PIPE:
 				r.Type = Recipient_PIPE
+			case aliases.FORWARD:
+				r.Type = Recipient_FORWARD
+				r.Via = aliasRcpt.Via
 			default:
 				log.Errorf("unknown alias type %v when resolving %q",
 					aliasRcpt.Type, t)
@@ -307,7 +315,7 @@ func (item *Item) SendLoop(q *Queue) {
 	defer tr.Finish()
 	tr.Printf("from %s", item.From)
 
-	for time.Since(item.CreatedAt) < giveUpAfter {
+	for time.Since(item.CreatedAt) < q.GiveUpAfter {
 		// Send to all recipients that are still pending.
 		var wg sync.WaitGroup
 		for _, rcpt := range item.Rcpt {
@@ -392,6 +400,21 @@ func (item *Item) deliver(q *Queue, rcpt *Recipient) (err error, permanent bool)
 		return cmd.Run(), true
 	}
 
+	// Recipient type is FORWARD: we always use the remote courier, and pass
+	// the list of servers that was given to us.
+	if rcpt.Type == Recipient_FORWARD {
+		deliverAttempts.Add("forward", 1)
+
+		// When forwarding with an explicit list of servers, we use SRS if
+		// we're sending from a non-local domain (regardless of the
+		// destination).
+		from := item.From
+		if !envelope.DomainIn(item.From, q.localDomains) {
+			from = rewriteSender(item.From, rcpt.OriginalAddress)
+		}
+		return q.remoteC.Forward(from, rcpt.Address, item.Data, rcpt.Via)
+	}
+
 	// Recipient type is EMAIL.
 	if envelope.DomainIn(rcpt.Address, q.localDomains) {
 		deliverAttempts.Add("email:local", 1)
@@ -401,24 +424,32 @@ func (item *Item) deliver(q *Queue, rcpt *Recipient) (err error, permanent bool)
 	deliverAttempts.Add("email:remote", 1)
 	from := item.From
 	if !envelope.DomainIn(item.From, q.localDomains) {
-		// We're sending from a non-local to a non-local. This should
-		// happen only when there's an alias to forward email to a
-		// non-local domain.  In this case, using the original From is
-		// problematic, as we may not be an authorized sender for this.
-		// Some MTAs (like Exim) will do it anyway, others (like
-		// gmail) will construct a special address based on the
-		// original address.  We go with the latter.
-		// Note this assumes "+" is an alias suffix separator.
-		// We use the IDNA version of the domain if possible, because
-		// we can't know if the other side will support SMTPUTF8.
-		from = fmt.Sprintf("%s+fwd_from=%s@%s",
-			envelope.UserOf(rcpt.OriginalAddress),
-			strings.Replace(from, "@", "=", -1),
-			mustIDNAToASCII(envelope.DomainOf(rcpt.OriginalAddress)))
+		// We're sending from a non-local to a non-local, need to do SRS.
+		from = rewriteSender(item.From, rcpt.OriginalAddress)
 	}
 	return q.remoteC.Deliver(from, rcpt.Address, item.Data)
 }
 
+func rewriteSender(from, originalAddr string) string {
+	// Apply a send-only Sender Rewriting Scheme (SRS).
+	// This is used when we are sending from a (potentially) non-local domain,
+	// to a non-local domain.
+	// This should happen only when there's an alias to forward email to a
+	// non-local domain (either a normal "email" alias with a remote
+	// destination, or a "forward" alias with a list of servers).
+	// In this case, using the original From is problematic, as we may not be
+	// an authorized sender for this.
+	// To do this, we use a sender rewriting scheme, similar to what other
+	// MTAs do (e.g. gmail or postfix).
+	// Note this assumes "+" is an alias suffix separator.
+	// We use the IDNA version of the domain if possible, because
+	// we can't know if the other side will support SMTPUTF8.
+	return fmt.Sprintf("%s+fwd_from=%s@%s",
+		envelope.UserOf(originalAddr),
+		strings.Replace(from, "@", "=", -1),
+		mustIDNAToASCII(envelope.DomainOf(originalAddr)))
+}
+
 // countRcpt counts how many recipients are in the given status.
 func (item *Item) countRcpt(statuses ...Recipient_Status) int {
 	c := 0
@@ -485,7 +516,7 @@ func nextDelay(createdAt time.Time) time.Duration {
 
 	// Perturb the delay, to avoid all queued emails to be retried at the
 	// exact same time after a restart.
-	delay += time.Duration(rand.Intn(60)) * time.Second
+	delay += rand.N(60 * time.Second)
 	return delay
 }
 
