@@ -3,7 +3,6 @@
 // Note that "report" mode is not supported.
 //
 // Reference: https://tools.ietf.org/html/rfc8461
-//
 package sts
 
 import (
@@ -14,14 +13,12 @@ import (
 	"errors"
 	"fmt"
 	"io"
-	"io/ioutil"
 	"mime"
 	"net"
 	"net/http"
 	"os"
 	"strconv"
 	"strings"
-	"sync"
 	"time"
 
 	"blitiri.com.ar/go/chasquid/internal/expvarom"
@@ -267,7 +264,7 @@ func httpGet(ctx context.Context, url string) ([]byte, error) {
 
 	// Read but up to 10k; policies should be way smaller than that, and
 	// having a limit prevents abuse/accidents with very large replies.
-	return ioutil.ReadAll(&io.LimitedReader{R: resp.Body, N: 10 * 1024})
+	return io.ReadAll(&io.LimitedReader{R: resp.Body, N: 10 * 1024})
 }
 
 var errRejectRedirect = errors.New("redirects not allowed in MTA-STS")
@@ -347,8 +344,6 @@ func hasSTSRecord(domain string) (bool, error) {
 // now disk is good enough for our purposes.
 type PolicyCache struct {
 	dir string
-
-	sync.Mutex
 }
 
 // NewCache creates an instance of PolicyCache using the given directory as
@@ -386,7 +381,7 @@ func (c *PolicyCache) load(domain string) (*Policy, error) {
 		return nil, errExpired
 	}
 
-	data, err := ioutil.ReadFile(fname)
+	data, err := os.ReadFile(fname)
 	if err != nil {
 		cacheIOErrors.Add(1)
 		return nil, err
@@ -487,7 +482,7 @@ func (c *PolicyCache) refresh(ctx context.Context) {
 	tr := trace.New("STSCache.Refresh", c.dir)
 	defer tr.Finish()
 
-	entries, err := ioutil.ReadDir(c.dir)
+	entries, err := os.ReadDir(c.dir)
 	if err != nil {
 		tr.Errorf("failed to list directory %q: %v", c.dir, err)
 		return
