@@ -1,9 +1,10 @@
 #!/bin/bash
 
 set -e
-. $(dirname ${0})/../util/lib.sh
+. "$(dirname "$0")/../util/lib.sh"
 
 init
+check_hostaliases
 
 mkdir -p .logs
 
@@ -11,15 +12,9 @@ if ! chasquid --version > /dev/null; then
 	fail "chasquid --version failed"
 fi
 
-# This should fail, as it has no certificates.
-rm -f config/certs/testserver/*.pem
-if chasquid -v=2 --logfile=.logs/chasquid.log --config_dir=config; then
-	fail "chasquid should not start without certificates"
-fi
-
 generate_certs_for testserver
-add_user user@testserver secretpassword
-add_user someone@testserver secretpassword
+chasquid-util-user-add user@testserver secretpassword
+chasquid-util-user-add someone@testserver secretpassword
 
 chasquid -v=2 --logfile=.logs/chasquid.log --config_dir=config &
 wait_until_ready 1025
@@ -42,7 +37,7 @@ if ! run_msmtp -a subm_tls someone@testserver < content 2> /dev/null; then
 fi
 
 if run_msmtp nobody@testserver < content 2> /dev/null; then
-	fail "successfuly sent an email to a non-existent user"
+	fail "successfully sent an email to a non-existent user"
 fi
 
 if run_msmtp -a baduser someone@testserver < content 2> /dev/null; then
