@@ -4,6 +4,7 @@
 // Note that chasquid does NOT support this, we do it before starting up the
 // daemon for testing purposes only.
 //
+//go:build ignore
 // +build ignore
 
 package main
@@ -11,7 +12,7 @@ package main
 import (
 	"flag"
 	"fmt"
-	"io/ioutil"
+	"io"
 	"os"
 	"time"
 
@@ -28,7 +29,7 @@ var (
 func main() {
 	flag.Parse()
 
-	data, err := ioutil.ReadAll(os.Stdin)
+	data, err := io.ReadAll(os.Stdin)
 	if err != nil {
 		fmt.Printf("error reading data: %v\n", err)
 		os.Exit(1)
