@@ -5,29 +5,27 @@
 # capitalizations.
 
 set -e
-. $(dirname ${0})/../util/lib.sh
+. "$(dirname "$0")/../util/lib.sh"
 
 init
 
-skip_if_python_is_too_old
-
 generate_certs_for ñoños
 
 # Intentionally have a config directory for upper case; this should be
 # normalized to lowercase internally (and match the cert accordingly).
+add_user ñandú@ñoñOS araño
 add_user ñangapirí@ñoñOS antaño
 
-# Python doesn't support UTF8 for auth, use an ascii user and domain.
-add_user nada@nada nada
-
 mkdir -p .logs
 chasquid -v=2 --logfile=.logs/chasquid.log --config_dir=config &
-wait_until_ready 1025
+wait_until_ready 1465
 
-# The envelope from and to are taken from the content, and use a mix of upper
-# and lower case.
-smtpc.py --server=localhost:1025 --user=nada@nada --password=nada \
-	< content
+# Use a mix of upper and lower case in the from, to, and username, to check
+# normalization is well handled end-to-end.
+smtpc --addr=localhost:1465 \
+	--server_cert=config/certs/ñoños/fullchain.pem \
+	--user=ñanDÚ@ñoños --password=araño \
+	Ñangapirí@Ñoños < content
 
 # The MDA should see the normalized users and domains, in lower case.
 wait_for_file .mail/ñangapirí@ñoños
