@@ -3,7 +3,7 @@
 # Test TLS tracking features, which require faking SPF.
 
 set -e
-. $(dirname ${0})/../util/lib.sh
+. "$(dirname "$0")/../util/lib.sh"
 
 init
 check_hostaliases
@@ -20,10 +20,10 @@ minidns_bg --addr=":9053" -zones=zones >> .minidns.log 2>&1
 # B - listens on :2025, hosts srv-B
 
 CONFDIR=A generate_certs_for srv-A
-CONFDIR=A add_user userA@srv-A userA
+CONFDIR=A add_user usera@srv-A userA
 
 CONFDIR=B generate_certs_for srv-B
-CONFDIR=B add_user userB@srv-B userB
+CONFDIR=B add_user userb@srv-B userB
 
 rm -rf .data-A .data-B .mail .certs
 mkdir -p .logs-A .logs-B .mail .certs
@@ -45,7 +45,7 @@ wait_until_ready 1025
 wait_until_ready 2025
 wait_until_ready 9053
 
-run_msmtp userB@srv-B < content
+smtpc userB@srv-B < content
 
 wait_for_file .mail/userb@srv-b
 mail_diff content .mail/userb@srv-b
@@ -62,5 +62,19 @@ then
 	fail "B is missing the domaininfo for srv-a"
 fi
 
+# In A, remove domaininfo data about srv-B.
+# Check that it was cleared successfully.
+CONFDIR=A chasquid-util domaininfo-remove srv-b
+if grep -q 'outgoing_sec_level:' ".data-A/domaininfo/s:srv-b";
+then
+	fail "Error clearing A's domaininfo about srv-b"
+fi
+
+# While at it, check that a domaininfo-remove for an unknown domain results in
+# an error.
+if CONFDIR=A chasquid-util domaininfo-remove srv-X > .cdu-di-r-x.log 2>&1; then
+	fail "Expected error on chasquid-util domaininfo-remove srv-X"
+fi
+
 success
 
