@@ -5,7 +5,7 @@
 # main gaps.
 
 set -e
-. $(dirname ${0})/../util/lib.sh
+. "$(dirname "$0")/../util/lib.sh"
 
 init
 check_hostaliases
@@ -18,10 +18,10 @@ export GOTAGS="dnsoverride"
 # B - listens on :2025, hosts srv-B
 
 CONFDIR=A generate_certs_for srv-A
-CONFDIR=A add_user userA@srv-A userA
+CONFDIR=A add_user usera@srv-A userA
 
 CONFDIR=B generate_certs_for srv-B
-CONFDIR=B add_user userB@srv-B userB
+CONFDIR=B add_user userb@srv-B userB
 
 rm -rf .data-A .data-B .mail .certs
 mkdir -p .logs-A .logs-B .mail .certs
@@ -44,17 +44,17 @@ wait_until_ready 2025
 
 function launch_minidns() {
 	if [ "$MINIDNS" != "" ]; then
-		kill $MINIDNS
-		wait $MINIDNS || true
+		kill "$MINIDNS"
+		wait "$MINIDNS" || true
 	fi
-	cp $1 .zones
+	cp "$1" .zones
 	minidns_bg --addr=":9053" -zones=.zones >> .minidns.log 2>&1
 	wait_until_ready 9053
 }
 
 # T0: Successful.
 launch_minidns zones.t0
-run_msmtp userB@srv-B < content
+smtpc userB@srv-B < content
 wait_for_file .mail/userb@srv-b
 mail_diff content .mail/userb@srv-b
 
@@ -62,7 +62,7 @@ mail_diff content .mail/userb@srv-b
 # Check that userA got a DSN about it.
 rm .mail/*
 launch_minidns zones.t1
-run_msmtp userB@srv-B < content
+smtpc userB@srv-B < content
 wait_for_file .mail/usera@srv-a
 mail_diff expected_dsn .mail/usera@srv-a
 
