@@ -1,7 +1,7 @@
 #!/bin/bash
 
 set -e
-. $(dirname ${0})/../util/lib.sh
+. "$(dirname "$0")/../util/lib.sh"
 
 init
 check_hostaliases
@@ -10,7 +10,6 @@ mkdir -p .logs
 
 if ! haproxy -v > /dev/null; then
 	skip "haproxy binary not found"
-	exit 0
 fi
 
 # Set a 2m timeout: if there are issues with haproxy, the wait tends to hang
